#ifndef PWDIALOG_H
#define PWDIALOG_H

#include <QDialog>

namespace Ui
{
class PWDialog;
}
class PWDialog : public QDialog
{
    Q_OBJECT

public:
    PWDialog(QWidget *parent = 0);
    ~PWDialog();

private:
    Ui::PWDialog *ui;
};
#endif // PWDIALOG_H
